<?php
	/**
	 * Bootstrap on Wordpress functions and definitions
	 *
	 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
	 *
	 * @package 	WordPress
	 * @subpackage 	Bootstrap 5.1.0
	 * @autor 		Firmbee
	 */

	define('BOOTSTRAP_VERSION', '5.0.2');

	/* ========================================================================================================================

	Add language support to theme

	======================================================================================================================== */
	add_action('after_setup_theme', 'my_theme_setup');
	function my_theme_setup(){
		load_theme_textdomain('firmbee_software_house', get_template_directory() . '/language');
	}



	/* ========================================================================================================================

	Required external files

	======================================================================================================================== */

	require_once( 'external/bootstrap-utilities.php' );
	require_once( 'external/bs5navwalker.php' );

	/* ========================================================================================================================

	Add html 5 support to wordpress elements

	======================================================================================================================== */

	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
		'caption',
	) );


	/* ========================================================================================================================

	Add footer widgets

	======================================================================================================================== */
	function register_widget_areas() {

		register_sidebar( array(
		  'name'          => 'Copyright footer',
		  'id'            => 'copyright-footer',
		  'description'   => 'adding copyright text',
		  'before_sidebar' => ' <div clas="copyright">',
		  'before_sidebar'  => '</div>',
		));

		register_sidebar( array(
			'name'          => 'About company footer',
			'id'            => 'about-company-footer',
			'description'   => 'Adding about company information and social media links in the first footer column',
			'before_sidebar' => ' <div class="about">',
			'after_sidebar'  => '</div>',

		  )); 

		register_sidebar( array(
			'name'          => 'Useful links',
			'id'            => 'useful-links',
			'description'   => 'adding useful links in the third footer column',
			'before_sidebar' => ' <div class="useful-links"><h6>Useful links</h6>',
			'after_sidebar'  => '</div>',
		  ));

		  register_sidebar( array(
			'name'          => 'Newsletter',
			'id'            => 'newsletter',
			'description'   => 'Forth footer column',
			'before_sidebar' => ' <div class="newsletter"><h6>Newsletter</h6>',
			'after_sidebar'  => '</div>',
		  ));

		  
		
	  }
	  
	  add_action( 'widgets_init', 'register_widget_areas' );


	  
	/* ========================================================================================================================

	Theme specific settings

	======================================================================================================================== */

	add_theme_support('post-thumbnails');
	add_theme_support('widgets');

	//add_image_size( 'name', width, height, crop true|false );

	register_nav_menus(array('primary' => 'Primary Navigation','footer_menu'  => 'Footer Menu'));

	/* ========================================================================================================================

	Actions and Filters

	======================================================================================================================== */

	add_action( 'wp_enqueue_scripts', 'bootstrap_script_init' );

	add_filter( 'body_class', array( 'BsWp', 'add_slug_to_body_class' ) );

	/* ========================================================================================================================

	Custom Post Types - include custom post types and taxonomies here e.g.

	e.g. require_once( 'custom-post-types/your-custom-post-type.php' );

	======================================================================================================================== */



	/* ========================================================================================================================

	Scripts

	======================================================================================================================== */

	/**
	 * Add scripts via wp_head()
	 *
	 * @return void
	 * @author Keir Whitaker
	 */
	if ( !function_exists( 'bootstrap_script_init' ) ) {
		function bootstrap_script_init() {

			// Get theme version number (located in style.css)
			$theme = wp_get_theme();


			wp_register_script('bootstrap', get_template_directory_uri() . '/js/bootstrap.bundle.min.js', array( 'jquery' ), BOOTSTRAP_VERSION, true);
			wp_enqueue_script('bootstrap');

			wp_register_script( 'site', get_template_directory_uri() . '/js/site.js', array( 'jquery', 'bootstrap' ), $theme->get( 'Version' ), true );
			wp_enqueue_script( 'site' );

			wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), BOOTSTRAP_VERSION, 'all' );
			wp_enqueue_style( 'bootstrap' );

			wp_register_style( 'screen', get_template_directory_uri() . '/style.css', array(), $theme->get( 'Version' ), 'screen' );
			wp_enqueue_style( 'screen' );

			wp_register_style( 'main', get_template_directory_uri() . '/css/main.css', array(), 1.0, 'all' );
			wp_enqueue_style( 'main' );

			wp_register_script( 'fontawesome', "https://kit.fontawesome.com/0e035b9984.js", array(), 1.0, 'all' );
			wp_enqueue_script( 'fontawesome' );

		}
	}

		function google_fonts() {
			wp_enqueue_style( 'google-fonts', 'https://fonts.googleapis.com/css2?family=Lato:wght@400;700;900&display=swap', false );
		}
		add_action( 'wp_enqueue_scripts', 'google_fonts' );

	/* ========================================================================================================================

	Security & cleanup wp admin

	======================================================================================================================== */

	//remove wp version
	function theme_remove_version() {
		return '';
	}

	add_filter('the_generator', 'theme_remove_version');

	//remove default footer text
	function remove_footer_admin () {
		echo "";
	}

	add_filter('admin_footer_text', 'remove_footer_admin');

	//remove wordpress logo from adminbar
	function wp_logo_admin_bar_remove() {
		global $wp_admin_bar;

		/* Remove their stuff */
		$wp_admin_bar->remove_menu('wp-logo');
	}

	add_action('wp_before_admin_bar_render', 'wp_logo_admin_bar_remove', 0);

	// Remove default Dashboard widgets
	if ( !function_exists( 'disable_default_dashboard_widgets' ) ) {
		function disable_default_dashboard_widgets() {

			//remove_meta_box('dashboard_right_now', 'dashboard', 'core');
			remove_meta_box('dashboard_activity', 'dashboard', 'core');
			remove_meta_box('dashboard_recent_comments', 'dashboard', 'core');
			remove_meta_box('dashboard_incoming_links', 'dashboard', 'core');
			remove_meta_box('dashboard_plugins', 'dashboard', 'core');
	
			remove_meta_box('dashboard_quick_press', 'dashboard', 'core');
			remove_meta_box('dashboard_recent_drafts', 'dashboard', 'core');
			remove_meta_box('dashboard_primary', 'dashboard', 'core');
			remove_meta_box('dashboard_secondary', 'dashboard', 'core');
		}
	}
	add_action('admin_menu', 'disable_default_dashboard_widgets');

	remove_action('welcome_panel', 'wp_welcome_panel');

	// Disable the emoji's
	if ( !function_exists( 'disable_emojis' ) ) {
		function disable_emojis() {
			remove_action('wp_head', 'print_emoji_detection_script', 7);
			remove_action('admin_print_scripts', 'print_emoji_detection_script');
			remove_action('wp_print_styles', 'print_emoji_styles');
			remove_action('admin_print_styles', 'print_emoji_styles');
			remove_filter('the_content_feed', 'wp_staticize_emoji');
			remove_filter('comment_text_rss', 'wp_staticize_emoji');
			remove_filter('wp_mail', 'wp_staticize_emoji_for_email');

			// Remove from TinyMCE
			add_filter('tiny_mce_plugins', 'disable_emojis_tinymce');
		}
	}
	add_action('init', 'disable_emojis');

	// Filter out the tinymce emoji plugin.
	function disable_emojis_tinymce($plugins) {
		if (is_array($plugins)) {
			return array_diff($plugins, array('wpemoji'));
		} else {
			return array();
		}
	}

	add_action('admin_head', 'custom_logo_guttenberg');

	if ( !function_exists( 'custom_logo_guttenberg' ) ) {
		function custom_logo_guttenberg() {
			echo '<link rel="stylesheet" type="text/css" href="'.get_bloginfo('stylesheet_directory').
			'/css/admin-custom.css?v=1.0.0" />';
		}
	}

 

	/* ========================================================================================================================

	Custom login

	======================================================================================================================== */

	// Add custom css
	if ( !function_exists( 'my_custom_login' ) ) {
		function my_custom_login() {
			echo '<link rel="stylesheet" type="text/css" href="' . get_bloginfo('stylesheet_directory') . '/css/custom-login-style.css?v=1.0.0" />';
		}
	}
	add_action('login_head', 'my_custom_login');

	// Link the logo to the home of our website
	if ( !function_exists( 'my_login_logo_url' ) ) {
		function my_login_logo_url() {
			return get_bloginfo( 'url' );
		}
	}
	add_filter( 'login_headerurl', 'my_login_logo_url' );

	// Change the title text
	if ( !function_exists( 'my_login_logo_url_title' ) ) {
	function my_login_logo_url_title() {
		return get_bloginfo( 'name' );
	}
	}
	add_filter( 'login_headertext', 'my_login_logo_url_title' );

	

	/* ========================================================================================================================

	Comments

	======================================================================================================================== */

	/**
	 * Custom callback for outputting comments
	 *
	 * @return void
	 * @author Keir Whitaker
	 */
	if (!function_exists( 'bootstrap_comment' )) {
		function bootstrap_comment( $comment, $args, $depth ) {
			$GLOBALS['comment'] = $comment;
			?>
			<?php if ( $comment->comment_approved == '1' ): ?>
			<li class="row">
				<div class="col-sm-2 mb-3">
					<?php echo get_avatar( $comment ); ?>
				</div>
				<div class="col-sm-10">
					<p><strong><?php comment_author_link() ?></strong></p>
					<p class="comments-date text-muted"><a href="#comment-<?php comment_ID() ?>" pubdate><?php comment_date('d m Y') ?> at <?php comment_time() ?></a></p>
					<p><?php comment_text() ?></p>
				</div>
			<?php endif;
		}
	}

	function positronx_set_post_views($post_id) {
		$count_key = 'wp_post_views_count';
		$count = get_post_meta($post_id, $count_key, true);
		 
		if($count == '') {
			$count = 0;
			delete_post_meta($post_id, $count_key);
			add_post_meta($post_id, $count_key, '0');
		} else {
			$count++;
			update_post_meta($post_id, $count_key, $count);
		}
	}

	function positronx_track_post_views ($post_id) {
		if ( !is_single() ) 
		return;
		 
		if ( empty ( $post_id) ) {
			global $post;
			$post_id = $post->ID;    
		}
		 
		positronx_set_post_views($post_id);
	}
	 
	add_action( 'wp_head', 'positronx_track_post_views');
	
	
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);


